/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Logs.Test
{
    using System;
    using System.Threading;

    using Phoenix.Log.Writer;

    class TestLog
    {
        #region Fields

        private object locker = new object();
        private int loops = 50;
        private ILogger threadLogger;

        #endregion Fields

        #region Constructors

        public TestLog()
        {
        }

        #endregion Constructors

        #region Events

        /// <summary>
        /// Occurs when multi threading logging is finished.
        /// </summary>
        public event EventHandler<EventArgs> ThreadAFinished;

        public event EventHandler<EventArgs> ThreadBFinished;

        #endregion Events

        #region Methods

        /// <summary>
        /// Configures logger with default configuration.
        /// </summary>
        public void ConfigureWithDefault()
        {
            LogManager.Configure(new DefaultConfigurator());
        }

        /// <summary>
        /// Configures logger with XML config file.
        /// </summary>
        public void ConfigureWithXml()
        {
            LogManager.Configure(new XmlConfigurator());
        }

        /// <summary>
        /// Setup logs with config file and log all kind of logs.
        /// </summary>
        public void TestConfigFile()
        {
            this.ConfigureWithXml();
            ILogger log = LogManager.GetLogger(typeof(TestLog));
            System.Console.WriteLine("==========================================================================");
            System.Console.WriteLine("=======TEST WITH CONFIGURATION FILE=======================================");
            System.Console.WriteLine("==========================================================================");
            System.Console.WriteLine("==========================================================================");

            log.Fatal("(CONFIGURATION FILE)");
            log.Error("(CONFIGURATION FILE)");
            log.Warning("(CONFIGURATION FILE)");
            log.Info("(CONFIGURATION FILE)");
            log.Debug("(CONFIGURATION FILE)");
            log.Flag("(CONFIGURATION FILE)");
        }

        /// <summary>
        /// Setup log with default configurator and log a fatal error.
        /// </summary>
        public void TestDefault()
        {
            this.ConfigureWithDefault();
            ILogger log = LogManager.GetLogger(typeof(TestLog));
            System.Console.WriteLine("==========================================================================");
            System.Console.WriteLine("=======TEST WITH DEFAULT CONFIGURATION====================================");
            System.Console.WriteLine("==========================================================================");
            System.Console.WriteLine("==========================================================================");

            log.Fatal("(DEFAULT CONFIGURATION)");
        }

        /// <summary>
        /// Tests the logger in multi threading environment.
        /// </summary>
        /// <param name="loop">The loop.</param>
        public void TestMultiThreading(int loop)
        {
            this.threadLogger = LogManager.GetLogger(typeof(TestLog));

            Thread threadA = new Thread(new ThreadStart(LoggerA));
            threadA.Name = "Thread A";

            Thread threadB = new Thread(new ThreadStart(LoggerB));
            threadB.Name = "Thread B";

            threadA.Start();
            threadB.Start();
        }

        /// <summary>
        /// Test the LogManager.GetLogger method to see if previous configuration
        /// still wotk if called from somewhere else.
        /// </summary>
        public void TestWithPreconfigure()
        {
            ILogger log = LogManager.GetLogger(typeof(TestLog));

            System.Console.WriteLine("==========================================================================");
            System.Console.WriteLine("=======TEST WITH PRECONFIGURED LOGS=======================================");
            System.Console.WriteLine("==========================================================================");
            System.Console.WriteLine("==========================================================================");

            log.Fatal("(PRECONFIGURED)");
            log.Error("(PRECONFIGURED)");
            log.Warning("(PRECONFIGURED)");
            log.Info("(PRECONFIGURED)");
            log.Debug("(PRECONFIGURED)");
            log.Flag("(PRECONFIGURED)");
        }

        private void LoggerA()
        {
            int loops;
            if (this.threadLogger == null)
                throw new ArgumentException("[Thread A] The ILogger is not set for the multi thread test!");

            lock (this.locker)
                loops = this.loops;

            for (int i = 0; i < loops; i++)
            {
                this.threadLogger.Info("AAAAAAAAAAAAAA");
            }
            this.OnThreadAFinished();
        }

        private void LoggerB()
        {
            int loops;
            if (this.threadLogger == null)
                throw new ArgumentException("[Thread B] The ILogger is not set for the multi thread test!");

            lock (this.locker)
                loops = this.loops;

            for (int i = 0; i < loops; i++)
            {
                this.threadLogger.Info("BBBBBBBBBBBBBB");
            }
            this.OnThreadBFinished();
        }

        private void OnThreadAFinished()
        {
            if (this.ThreadAFinished != null)
                this.ThreadAFinished(this, EventArgs.Empty);
        }

        private void OnThreadBFinished()
        {
            if (this.ThreadBFinished != null)
                this.ThreadBFinished(this, EventArgs.Empty);
        }

        #endregion Methods
    }
}