/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
namespace Phoenix.Log
{
    using System;
    using System.Collections.Generic;

    /// <summary>
    /// Represent an error entry in the log repository
    /// </summary>
    public interface IRow
    {
        #region Properties

        /// <summary>
        /// Gets or sets the base log.
        /// </summary>
        /// <value>The base log.</value>
        IRow BaseLog
        {
            get; set;
        }

        /// <summary>
        /// Gets the base log key.
        /// </summary>
        /// <value>The base log key.</value>
        Guid BaseLogKey
        {
            get;
        }

        /// <summary>
        /// Gets or sets the deepness in the inner logs scale.
        /// </summary>
        /// <value>The deepness.</value>
        int Deepness
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the exception message.
        /// </summary>
        /// <value>The exception message.</value>
        string ExceptionMessage
        {
            get; set;
        }

        /// <summary>
        /// Gets the log's insertion date.
        /// </summary>
        /// <value>The insert date.</value>
        DateTime InsertDate
        {
            get;
        }

        /// <summary>
        /// Gets the key that represents assembly primary key.
        /// </summary>
        /// <value>The key.</value>
        Guid Key
        {
            get;
        }

        /// <summary>
        /// Gets the numeric value of the log type <see cref="Stamp"/>.
        /// </summary>
        /// <value>The log type value.</value>
        int LogTypeValue
        {
            get;
        }

        /// <summary>
        /// Gets or sets the message of the log entry.
        /// </summary>
        /// <value>The message.</value>
        string Message
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the source of the error.
        /// </summary>
        /// <value>The source.</value>
        string Source
        {
            get; set;
        }

        /// <summary>
        /// Gets or sets the stack trace of the error.
        /// </summary>
        /// <value>The stack trace.</value>
        string StackTrace
        {
            get; set;
        }

        /// <summary>
        /// Gets the type of the log.
        /// </summary>
        /// <value>The type of the log.</value>
        Stamp Stamp
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the title oof the log entry.
        /// </summary>
        /// <value>The title.</value>
        string Title
        {
            get;
            set;
        }

        #endregion Properties
    }
}