/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log.Writer
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;

    /// <summary>
    /// The Log is assembly container of <see cref="Log.Writer.IAppender"/> each call of assembly writing
    /// log method will execute the same method of all appenders contained into this Log class
    /// </summary>
    public interface ILogger
    {
        #region Properties

        /// <summary>
        /// Gets the list of appenders.
        /// </summary>
        /// <value>The appenders.</value>
        List<IAppender> Appenders
        {
            get;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Adds an appender.
        /// </summary>
        /// <param name="appender">The appender.</param>
        void AddAppender(IAppender appender);

        /// <summary>
        /// Log assembly debug entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Debug(string message);

        /// <summary>
        /// Log assembly debug entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Debug(string message, Exception exception);

        /// <summary>
        /// Log an error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Error(string message);

        /// <summary>
        /// Log an error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Error(string message, Exception exception);

        /// <summary>
        /// Log assembly fatal error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>        
        void Fatal(string message);

        /// <summary>
        /// Log assembly fatal error into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Fatal(string message, Exception exception);

        /// <summary>
        /// Log assembly flag into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Flag(string message);

        /// <summary>
        /// Log assembly flag into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Flag(string message, Exception exception);

        /// <summary>
        /// Log assembly info entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Info(string message);

        /// <summary>
        /// Log assembly info entry into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Info(string message, Exception exception);

        /// <summary>
        /// Inserts the specified error entry.
        /// </summary>
        /// <param name="errorEntry">The error entry.</param>
        void Insert(IRow errorEntry);

        /// <summary>
        /// Removes the specified appender from the list of appenders.
        /// </summary>
        /// <param name="appender">The appender.</param>
        /// <returns><c>true</c> if the deletion succeded. Otherwise <c>false</c></returns>
        bool RemoveAppender(IAppender appender);

        /// <summary>
        /// Sets the type of sender.
        /// </summary>
        /// <param name="typeOfSender">The type of sender.</param>
        void SetTypeOfSender(Type typeOfSender);

        /// <summary>
        /// Log assembly warning into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        void Warning(string message);

        /// <summary>
        /// Log assembly warning into the log repository.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="exception">The exception.</param>
        void Warning(string message, Exception exception);

        #endregion Methods
    }
}