﻿--SQLite Maestro 9.10.0.1
------------------------------------------
--Host     : localhost
--Database : C:\translations.db

--DROP TABLE BaseText;
--DROP TABLE Language;
--DROP TABLE Translation;
--DROP VIEW Translations;

CREATE TABLE BaseText (
  ID     integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  Value  text
);

/* Data for table BaseText */
INSERT INTO BaseText (ID, Value) VALUES (1, 'Hello');
INSERT INTO BaseText (ID, Value) VALUES (2, 'How are you?');
INSERT INTO BaseText (ID, Value) VALUES (3, 'My name is {0}.');
INSERT INTO BaseText (ID, Value) VALUES (4, 'What is your name?');

CREATE TRIGGER BaseText_CreateDefaultEnglishBeforeInsert
  AFTER INSERT
  ON BaseText
BEGIN
  INSERT INTO Translation (fk_Language, fk_BaseText, Value)
  VALUES (0, NEW.ID, NEW.Value);      
END;



CREATE TRIGGER BaseText_au_fkr_Translation
  AFTER UPDATE OF ID
  ON BaseText
BEGIN
  UPDATE Translation
  SET fk_BaseText = NEW.ID
  WHERE fk_BaseText = OLD.ID;
END;



CREATE TRIGGER BaseText_bd_fkr_Translation
  BEFORE DELETE
  ON BaseText
BEGIN
  DELETE FROM Translation
  WHERE fk_BaseText = OLD.ID;
END;



CREATE TABLE Language (
  ID           integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  Name         varchar(50) UNIQUE,
  Abreviation  varchar(3) UNIQUE,
  isActive     boolean NOT NULL DEFAULT 0
);


/* Data for table Language */
INSERT INTO Language (ID, Name, Abreviation, isActive) VALUES (0, 'English', 'EN', 0);
INSERT INTO Language (ID, Name, Abreviation, isActive) VALUES (1, 'Français', 'FR', 0);
INSERT INTO Language (ID, Name, Abreviation, isActive) VALUES (2, 'Español', 'ES', 1);

CREATE TRIGGER CheckLanguageTranslationCount
  BEFORE UPDATE OF isActive
  ON Language
BEGIN
  UPDATE Language
  SET isActive = 0;
  END;



CREATE TRIGGER Language_au_fkr_Translation
  AFTER UPDATE OF ID
  ON Language
BEGIN
  UPDATE Translation
  SET fk_Language = NEW.ID
  WHERE fk_Language = OLD.ID;
END;



CREATE TRIGGER Language_bd_fkr_Translation
  BEFORE DELETE
  ON Language
BEGIN
  DELETE FROM Translation
  WHERE fk_Language = OLD.ID;
END;



CREATE TABLE Translation (
  ID           integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  fk_Language  integer,
  fk_BaseText  integer,
  Value        text NOT NULL DEFAULT '',
  /* Foreign keys */
  FOREIGN KEY (fk_BaseText)
    REFERENCES BaseText(ID), 
  FOREIGN KEY (fk_Language)
    REFERENCES Language(ID)
);


/* Data for table Translation */
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (1, 0, 1, 'Hello');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (2, 0, 2, 'How are you?');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (3, 0, 3, 'My name is {0}.');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (4, 0, 4, 'What is your name?');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (5, 1, 1, 'Bonjour');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (6, 1, 2, 'Comment allez-vous?');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (7, 1, 3, 'Mon nom est {0}.');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (8, 1, 4, 'Quel est votre nom?');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (9, 2, 1, 'Hola');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (10, 2, 2, 'Còmo està usted?');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (11, 2, 3, 'Mi nombre es {0}.');
INSERT INTO Translation (ID, fk_Language, fk_BaseText, Value) VALUES (12, 2, 4, 'Como se llama usted?');

CREATE TRIGGER Translation_bi_fk_BaseText
  BEFORE INSERT
  ON Translation
BEGIN
  SELECT CASE
    WHEN (SELECT 1 FROM BaseText WHERE BaseText.ID = NEW.fk_BaseText) IS NULL
    THEN RAISE(ABORT, 'INSERT statement conflicted with COLUMN REFERENCE constraint [Translation -> BaseText].')
  END;
END;



CREATE TRIGGER Translation_bi_fk_Language
  BEFORE INSERT
  ON Translation
BEGIN
  SELECT CASE
    WHEN (SELECT 1 FROM Language WHERE Language.ID = NEW.fk_Language) IS NULL
    THEN RAISE(ABORT, 'INSERT statement conflicted with COLUMN REFERENCE constraint [Translation -> Language].')
  END;
END;



CREATE TRIGGER Translation_bu_fk_BaseText
  BEFORE UPDATE OF fk_BaseText
  ON Translation
BEGIN
  SELECT CASE
    WHEN (SELECT 1 FROM BaseText WHERE BaseText.ID = NEW.fk_BaseText) IS NULL
    THEN RAISE(ABORT, 'UPDATE statement conflicted with COLUMN REFERENCE constraint [Translation -> BaseText].')
  END;
END;



CREATE TRIGGER Translation_bu_fk_Language
  BEFORE UPDATE OF fk_Language
  ON Translation
BEGIN
  SELECT CASE
    WHEN (SELECT 1 FROM Language WHERE Language.ID = NEW.fk_Language) IS NULL
    THEN RAISE(ABORT, 'UPDATE statement conflicted with COLUMN REFERENCE constraint [Translation -> Language].')
  END;
END;



CREATE VIEW Translations
AS
SELECT
  BaseText.Value AS Value,
  Translation.Value AS TranslatedValue
FROM
  BaseText
  LEFT OUTER JOIN Translation ON (BaseText.ID = Translation.fk_BaseText)
  LEFT OUTER JOIN Language ON (Translation.fk_Language = Language.ID)
WHERE
     Language.isActive = 1
  OR Language.isActive IS NULL;
